@@ -52,28 +52,28 @@ function test_bounds()
         MOI.ConstraintConflictStatus(),
         index(UpperBoundRef(y)),
     ) == MOI.IN_CONFLICT
-    @test MOI.get(solver, MOIIS.ConflictCount()) == 1
+    @test MOI.get(solver, MOI.ConflictCount()) == 1
     @test MOI.get(
         solver,
-        MOIIS.ConstraintConflictStatus(1),
+        MOI.ConstraintConflictStatus(1),
         index(LowerBoundRef(y)),
     ) == MOI.IN_CONFLICT
     @test MOI.get(
         solver,
-        MOIIS.ConstraintConflictStatus(1),
+        MOI.ConstraintConflictStatus(1),
         index(UpperBoundRef(y)),
     ) == MOI.IN_CONFLICT
-    @test MOI.get(solver, MOIIS.ConstraintConflictStatus(1), index(c)) ==
+    @test MOI.get(solver, MOI.ConstraintConflictStatus(1), index(c)) ==
           MOI.NOT_IN_CONFLICT
     # the next two could be errors
     @test MOI.get(
         solver,
-        MOIIS.ConstraintConflictStatus(2),
+        MOI.ConstraintConflictStatus(2),
         index(LowerBoundRef(y)),
     ) == MOI.NOT_IN_CONFLICT
     @test MOI.get(
         solver,
-        MOIIS.ConstraintConflictStatus(2),
+        MOI.ConstraintConflictStatus(2),
         index(UpperBoundRef(y)),
     ) == MOI.NOT_IN_CONFLICT
     #
@@ -430,9 +430,9 @@ function test_pass_attribute()
     MOI.set(solver, MOIIS.InnerOptimizer(), HiGHS.Optimizer)
     MOI.set(solver, MOI.TimeLimitSec(), 5.0)
     @test MOI.get(solver, MOI.TimeLimitSec()) == 5.0
-    @test MOI.get(solver, MOI.Silent()) == false
-    MOI.set(solver, MOI.Silent(), true)
     @test MOI.get(solver, MOI.Silent()) == true
+    MOI.set(solver, MOI.Silent(), false)
+    @test MOI.get(solver, MOI.Silent()) == false
     @test MOI.get(solver, MOIIS.ElasticFilterTolerance()) == 1e-5
     MOI.set(solver, MOIIS.ElasticFilterTolerance(), 1e-3)
     @test MOI.get(solver, MOIIS.ElasticFilterTolerance()) == 1e-3
@@ -486,6 +486,9 @@ function test_iis()
     @test data[].irreducible
     @test data[].metadata == MOIIS.NoData()
     @test _isequal_unordered(data[].constraints, [index(c2), index(c1)])
+    MOI.set(solver, MOIIS.InfeasibleModel(), backend(model))
+    @test isempty(solver.results)
+    @test solver.status == MOI.COMPUTE_CONFLICT_NOT_CALLED
     return
 end
 
@@ -746,6 +749,13 @@ function test_iis_binary()
     return
 end
 
+function test_deprecated()
+    @test (@test_deprecated MOIIS.ConflictCount()) == MOI.ConflictCount()
+    @test (@test_deprecated MOIIS.ConstraintConflictStatus(2)) ==
+          MOI.ConstraintConflictStatus(2)
+    return
+end
+
 end # module
 
 TestMathOptIIS.runtests()
